==> jc-1.4.0.tar.gz: gnu/xml/util/SAXNullTransformerFactory__24DomHandler.h <==
// class gnu.xml.util.SAXNullTransformerFactory$DomHandler

// class file dependencies
// @dep_class 154cf6a1b6f6caf gnu_xml_dom_Consumer__24Backdoor
// @dep_class 30be1743269d6892 gnu_xml_pipeline_DomConsumer__24Handler
// @dep_class 4643c56cfe1144c2 gnu_xml_util_SAXNullTransformerFactory__24DomHandler
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_dom_Consumer__24Backdoor

#include "gnu/xml/dom/Consumer__24Backdoor.h"

#ifndef _JC_gnu_xml_util_SAXNullTransformerFactory__24DomHandler_H_
#define _JC_gnu_xml_util_SAXNullTransformerFactory__24DomHandler_H_

// Forward structure declarations
struct _jc_gnu_xml_pipeline_DomConsumer$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_xml_transform_dom_DOMResult$object;

// Typedefs
typedef struct _jc_gnu_xml_util_SAXNullTransformerFactory__24DomHandler$sub_refs	_jc_gnu_xml_util_SAXNullTransformerFactory__24DomHandler$sub_refs;
typedef struct _jc_gnu_xml_util_SAXNullTransformerFactory__24DomHandler$sub_nonrefs	_jc_gnu_xml_util_SAXNullTransformerFactory__24DomHandler$sub_nonrefs;
typedef struct _jc_gnu_xml_util_SAXNullTransformerFactory__24DomHandler$refs	_jc_gnu_xml_util_SAXNullTransformerFactory__24DomHandler$refs;
typedef struct _jc_gnu_xml_util_SAXNullTransformerFactory__24DomHandler$nonrefs	_jc_gnu_xml_util_SAXNullTransformerFactory__24DomHandler$nonrefs;
typedef struct _jc_gnu_xml_util_SAXNullTransformerFactory__24DomHandler$object	_jc_gnu_xml_util_SAXNullTransformerFactory__24DomHandler$object;

typedef const struct _jc_gnu_xml_util_SAXNullTransformerFactory__24DomHandler$vmethods	_jc_gnu_xml_util_SAXNullTransformerFactory__24DomHandler$vmethods;
typedef const struct _jc_gnu_xml_util_SAXNullTransformerFactory__24DomHandler$vtable	_jc_gnu_xml_util_SAXNullTransformerFactory__24DomHandler$vtable;
typedef const struct _jc_gnu_xml_util_SAXNullTransformerFactory__24DomHandler$vtype	_jc_gnu_xml_util_SAXNullTransformerFactory__24DomHandler$vtype;

// Constructors
extern void _jc_gnu_xml_util_SAXNullTransformerFactory__24DomHandler$method$_init$040df2269d8a6871(_jc_env *, struct _jc_gnu_xml_util_SAXNullTransformerFactory__24DomHandler$object *, struct _jc_gnu_xml_pipeline_DomConsumer$object *, struct _jc_javax_xml_transform_dom_DOMResult$object *);

// Virtual methods
extern void _jc_gnu_xml_util_SAXNullTransformerFactory__24DomHandler$method$endDocument$4903a775f2613143(_jc_env *, struct _jc_gnu_xml_util_SAXNullTransformerFactory__24DomHandler$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_util_SAXNullTransformerFactory__24DomHandler$method_info$endDocument$4903a775f2613143;

// Virtual methods structure
struct _jc_gnu_xml_util_SAXNullTransformerFactory__24DomHandler$vmethods {
	void	(*endDocument$4903a775f2613143)(_jc_env *, struct _jc_gnu_xml_util_SAXNullTransformerFactory__24DomHandler$object *);
};

// Vtable
struct _jc_gnu_xml_util_SAXNullTransformerFactory__24DomHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_pipeline_DomConsumer__24Handler$vmethods	gnu_xml_pipeline_DomConsumer__24Handler;
	_jc_gnu_xml_dom_Consumer__24Backdoor$vmethods	gnu_xml_dom_Consumer__24Backdoor;
	_jc_gnu_xml_util_SAXNullTransformerFactory__24DomHandler$vmethods	gnu_xml_util_SAXNullTransformerFactory__24DomHandler;
};

// Vtype
struct _jc_gnu_xml_util_SAXNullTransformerFactory__24DomHandler$vtype {
	_jc_type			type;
	_jc_gnu_xml_util_SAXNullTransformerFactory__24DomHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_util_SAXNullTransformerFactory__24DomHandler$sub_refs {
	struct _jc_javax_xml_transform_dom_DOMResult$object	*result;
};

// Reference instance fields (object)
struct _jc_gnu_xml_util_SAXNullTransformerFactory__24DomHandler$refs {
    _jc_gnu_xml_util_SAXNullTransformerFactory__24DomHandler$sub_refs	gnu_xml_util_SAXNullTransformerFactory__24DomHandler;
    _jc_gnu_xml_dom_Consumer__24Backdoor$sub_refs	gnu_xml_dom_Consumer__24Backdoor;
    _jc_gnu_xml_pipeline_DomConsumer__24Handler$sub_refs	gnu_xml_pipeline_DomConsumer__24Handler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_util_SAXNullTransformerFactory__24DomHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_util_SAXNullTransformerFactory__24DomHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_pipeline_DomConsumer__24Handler$sub_nonrefs	gnu_xml_pipeline_DomConsumer__24Handler;
    _jc_gnu_xml_dom_Consumer__24Backdoor$sub_nonrefs	gnu_xml_dom_Consumer__24Backdoor;
    _jc_gnu_xml_util_SAXNullTransformerFactory__24DomHandler$sub_nonrefs	gnu_xml_util_SAXNullTransformerFactory__24DomHandler;
};

// Object instance structure
struct _jc_gnu_xml_util_SAXNullTransformerFactory__24DomHandler$object {
	_jc_gnu_xml_util_SAXNullTransformerFactory__24DomHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_util_SAXNullTransformerFactory__24DomHandler$vtype	*vtype;
	_jc_gnu_xml_util_SAXNullTransformerFactory__24DomHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_util_SAXNullTransformerFactory__24DomHandler$vtype _jc_gnu_xml_util_SAXNullTransformerFactory__24DomHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_util_SAXNullTransformerFactory__24DomHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_util_SAXNullTransformerFactory__24DomHandler$class_object;

#endif	/* _JC_gnu_xml_util_SAXNullTransformerFactory__24DomHandler_H_ */

==> jc-1.4.6.tar.gz: gnu/xml/util/SAXNullTransformerFactory__24DomHandler.h <==
// class gnu.xml.util.SAXNullTransformerFactory$DomHandler

// class file dependencies
// @dep_class 154cf6a1b6f6caf gnu_xml_dom_Consumer__24Backdoor
// @dep_class 30be1743269d6892 gnu_xml_pipeline_DomConsumer__24Handler
// @dep_class 4643c56cfe1144c2 gnu_xml_util_SAXNullTransformerFactory__24DomHandler
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_dom_Consumer__24Backdoor

#include "gnu/xml/dom/Consumer__24Backdoor.h"

#ifndef _JC_gnu_xml_util_SAXNullTransformerFactory__24DomHandler_H_
#define _JC_gnu_xml_util_SAXNullTransformerFactory__24DomHandler_H_

// Forward structure declarations
struct _jc_gnu_xml_pipeline_DomConsumer$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_xml_transform_dom_DOMResult$object;

// Typedefs
typedef struct _jc_gnu_xml_util_SAXNullTransformerFactory__24DomHandler$sub_refs	_jc_gnu_xml_util_SAXNullTransformerFactory__24DomHandler$sub_refs;
typedef struct _jc_gnu_xml_util_SAXNullTransformerFactory__24DomHandler$sub_nonrefs	_jc_gnu_xml_util_SAXNullTransformerFactory__24DomHandler$sub_nonrefs;
typedef struct _jc_gnu_xml_util_SAXNullTransformerFactory__24DomHandler$refs	_jc_gnu_xml_util_SAXNullTransformerFactory__24DomHandler$refs;
typedef struct _jc_gnu_xml_util_SAXNullTransformerFactory__24DomHandler$nonrefs	_jc_gnu_xml_util_SAXNullTransformerFactory__24DomHandler$nonrefs;
typedef struct _jc_gnu_xml_util_SAXNullTransformerFactory__24DomHandler$object	_jc_gnu_xml_util_SAXNullTransformerFactory__24DomHandler$object;

typedef const struct _jc_gnu_xml_util_SAXNullTransformerFactory__24DomHandler$vmethods	_jc_gnu_xml_util_SAXNullTransformerFactory__24DomHandler$vmethods;
typedef const struct _jc_gnu_xml_util_SAXNullTransformerFactory__24DomHandler$vtable	_jc_gnu_xml_util_SAXNullTransformerFactory__24DomHandler$vtable;
typedef const struct _jc_gnu_xml_util_SAXNullTransformerFactory__24DomHandler$vtype	_jc_gnu_xml_util_SAXNullTransformerFactory__24DomHandler$vtype;

// Constructors
extern void _jc_gnu_xml_util_SAXNullTransformerFactory__24DomHandler$method$_init$040df2269d8a6871(_jc_env *, struct _jc_gnu_xml_util_SAXNullTransformerFactory__24DomHandler$object *, struct _jc_gnu_xml_pipeline_DomConsumer$object *, struct _jc_javax_xml_transform_dom_DOMResult$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_gnu_xml_util_SAXNullTransformerFactory__24DomHandler$method$endDocument$4903a775f2613143(_jc_env *, struct _jc_gnu_xml_util_SAXNullTransformerFactory__24DomHandler$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_util_SAXNullTransformerFactory__24DomHandler$method_info$endDocument$4903a775f2613143;

// Virtual methods structure
struct _jc_gnu_xml_util_SAXNullTransformerFactory__24DomHandler$vmethods {
	void	(*endDocument$4903a775f2613143)(_jc_env *, struct _jc_gnu_xml_util_SAXNullTransformerFactory__24DomHandler$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_util_SAXNullTransformerFactory__24DomHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_pipeline_DomConsumer__24Handler$vmethods	gnu_xml_pipeline_DomConsumer__24Handler;
	_jc_gnu_xml_dom_Consumer__24Backdoor$vmethods	gnu_xml_dom_Consumer__24Backdoor;
	_jc_gnu_xml_util_SAXNullTransformerFactory__24DomHandler$vmethods	gnu_xml_util_SAXNullTransformerFactory__24DomHandler;
};

// Vtype
struct _jc_gnu_xml_util_SAXNullTransformerFactory__24DomHandler$vtype {
	_jc_type			type;
	_jc_gnu_xml_util_SAXNullTransformerFactory__24DomHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_util_SAXNullTransformerFactory__24DomHandler$sub_refs {
	struct _jc_javax_xml_transform_dom_DOMResult$object	*result;
};

// Reference instance fields (object)
struct _jc_gnu_xml_util_SAXNullTransformerFactory__24DomHandler$refs {
    _jc_gnu_xml_util_SAXNullTransformerFactory__24DomHandler$sub_refs	gnu_xml_util_SAXNullTransformerFactory__24DomHandler;
    _jc_gnu_xml_dom_Consumer__24Backdoor$sub_refs	gnu_xml_dom_Consumer__24Backdoor;
    _jc_gnu_xml_pipeline_DomConsumer__24Handler$sub_refs	gnu_xml_pipeline_DomConsumer__24Handler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_util_SAXNullTransformerFactory__24DomHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_util_SAXNullTransformerFactory__24DomHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_pipeline_DomConsumer__24Handler$sub_nonrefs	gnu_xml_pipeline_DomConsumer__24Handler;
    _jc_gnu_xml_dom_Consumer__24Backdoor$sub_nonrefs	gnu_xml_dom_Consumer__24Backdoor;
    _jc_gnu_xml_util_SAXNullTransformerFactory__24DomHandler$sub_nonrefs	gnu_xml_util_SAXNullTransformerFactory__24DomHandler;
};

// Object instance structure
struct _jc_gnu_xml_util_SAXNullTransformerFactory__24DomHandler$object {
	_jc_gnu_xml_util_SAXNullTransformerFactory__24DomHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_util_SAXNullTransformerFactory__24DomHandler$vtype	*vtype;
	_jc_gnu_xml_util_SAXNullTransformerFactory__24DomHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_util_SAXNullTransformerFactory__24DomHandler$vtype _jc_gnu_xml_util_SAXNullTransformerFactory__24DomHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_util_SAXNullTransformerFactory__24DomHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_util_SAXNullTransformerFactory__24DomHandler$class_object;

#endif	/* _JC_gnu_xml_util_SAXNullTransformerFactory__24DomHandler_H_ */
